机器人总动员 (豆瓣)
Description: 机器人总动员电影简介和剧情介绍,机器人总动员影评、图片、预告片、影讯、论坛、在线购票
Keywords: 机器人总动员,WALL·E,机器人总动员影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.15豆瓣电影Top250

# 机器人总动员 WALL·E (2008)

更新描述或海报

导演: 安德鲁·斯坦顿
编剧: 安德鲁·斯坦顿 / 吉姆·里尔顿 / 彼特·道格特
主演: 本·贝尔特 / 艾丽莎·奈特 / 杰夫·格尔林 / 佛莱德·威拉特 / 西格妮·韦弗 / MacInTalk / 约翰·拉岑贝格 / 凯茜·纳基麦 / 泰迪·牛顿 / 鲍伯·伯根 / 洛丽·理查德森 / 吉姆·瓦德 / 彼特·道格特 / 安德鲁·斯坦顿 / 杰夫·皮金 / 约翰·齐甘 / 米凯·麦高万 / 雪莉·琳恩 / 克莱特·惠特克 / 唐纳德·富利洛夫 / 罗里·艾伦 / 杰斯·哈梅尔 / 拉瑞恩·纽曼 / 扬·拉布森 / 保罗·伊丁
类型: 科幻 / 动画 / 冒险
官方网站: www.pixar.com/feature-films/walle
制片国家/地区: 美国
语言: 英语
上映日期: 2008-06-27(美国)
片长: 98分钟
又名: 太空奇兵·威E(港) / 瓦力(台) / 星际总动员 / 地球废品分装员 / 机器人瓦力 / walle
IMDb: tt0910970
豆瓣评分
引用
9.3
1256809人评价
5星
71.8%
4星
24.0%
3星
3.9%
2星
0.2%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
8.7
3人评价
好于 99% 动画片
好于 99% 科幻片
我看过这部电影 2020-07-12 修改
我的评价:
推荐

## 机器人总动员的剧情简介 · · · · · ·

公元2805年，人类文明高度发展，却因污染和生活垃圾大量增加使得地球不再适于人类居住。地球人被迫乘坐飞船离开故乡，进行一次漫长无边的宇宙之旅。临行前他们委托Buynlarge的公司对地球垃圾进行清理，该公司开发了名为WALL·E（Waste Allocation Load Lifters – Earth 地球废品分装员）的机器人担当此重任。
这些机器人按照程序日复一日、年复一年辛勤工作，但随着时间的流逝和恶劣环境的侵蚀，WALL·E们接连损坏、停止运动。最后只有一个仍在进行这项似乎永无止境的工作。经历了漫长的岁月，它开始拥有了自己的意识。它喜欢将收集来的宝贝小心翼翼藏起，喜欢收工后看看几百年前的歌舞片，此外还有一只蟑螂朋友作伴。直到有一天，一艘来自宇宙的飞船打破了它一成不变的生活……
本片荣获2009年第81届奥斯卡最佳动画长片奖。 ©豆瓣

## 机器人总动员的演职员 · · · · · · ( 全部 51 )

- 安德鲁·斯坦顿 导演
- 本·贝尔特 配 瓦力 / 莫 / 机器人 WALL·E / M-O / Robots
- 艾丽莎·奈特 配 伊芙 EVE
- 杰夫·格尔林 配 舰长迈克雷 Captain B. McCrea
- 佛莱德·威拉特 配 谢尔比·福斯雷特 Shelby Forthright
- 西格妮·韦弗 配 公理号计算机 Ship's Computer

## 机器人总动员的视频和图片 · · · · · · ( 预告片1 | 视频评论1 · 添加 | 图片855 · 添加 )

## 机器人总动员的获奖情况 · · · · · · ( 全部 )

- 第81届奥斯卡金像奖
- 最佳原创剧本(提名)
- 彼特·道格特 / 安德鲁·斯坦顿 / 吉姆·里尔顿

- 第66届金球奖
- 电影类 最佳动画长片

- 第36届动画安妮奖
- 最佳动画长片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  天空之城

  哈尔的移动城堡

  大闹天宫

  幽灵公主

  风之谷

  玩具总动员

  怪兽电力公司

  冰川时代

  飞屋环游记

  神偷奶爸

我要写短评

## 机器人总动员的短评 · · · · · · ( 全部 227062 条 )

热门 / 最新 / 好友

### 11033 有用 SWX 看过 2012-10-08 23:40:20

这是一只安卓和苹果的故事么。。

### 4683 有用 Ragdoll™ 看过 2009-01-23 15:00:46

乡下文艺小伙儿追求都市女精英的故事……以及……

### 1657 有用 眠去 看过 2008-11-03 08:21:09

没有引进真是太遗憾了。

### 1531 有用 眼角的花朵 看过 2008-07-10 11:35:55

人类在这个片子里面是处于完全被嘲笑的位置。（其实应该说美国人？）片中的超大型连锁企业BNL在未来已经统一了所有的商业领域。而人类堕落成完全依靠电脑的帮助才能吃喝拉撒的胖子们。而且从小就接受电脑的教育要消费消费再快点消费。这个世界虽然没有Matrix的灰暗，但是其实相差不远。好在人类并非丧失了本性，只是“遗忘”了而已。而Wall E和Eva的出现就提醒了他们还有一个“家”，虽然已经满目疮痍，在等待着... 人类在这个片子里面是处于完全被嘲笑的位置。（其实应该说美国人？）片中的超大型连锁企业BNL在未来已经统一了所有的商业领域。而人类堕落成完全依靠电脑的帮助才能吃喝拉撒的胖子们。而且从小就接受电脑的教育要消费消费再快点消费。这个世界虽然没有Matrix的灰暗，但是其实相差不远。好在人类并非丧失了本性，只是“遗忘”了而已。而Wall E和Eva的出现就提醒了他们还有一个“家”，虽然已经满目疮痍，在等待着他们的回归。 (展开)

### 6993 有用 徐小花 看过 2008-12-27 22:33:27

把所有的好东西都给eva

> 更多短评 227062条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 黑烟的圈 看过 2020-08-13 11:31:06

eva........

### 0 有用 LLudeer 看过 2014-11-09 17:38:08

没有多少台词 但就是好棒！

我要写影评

## 机器人总动员的影评 · · · · · · ( 全部 3104 条 )

热门 / 最新 / 好友
舞！舞！舞！ 2008-08-18 13:21:36

## 直到世界灭亡 依然对爱渴望。

也许这一刻，我正在庞大的超市门口拎了几个大袋子笨拙地走。Wall-e正在尘土满天的废弃城市里把一堆垃圾吃力地压成立方体。 也许下一刻，我已回到家里爬上床看连续剧，看其实老也跳不出窠臼的模式剧情。Wall-e已回到家里点起灯打开电视，看它仅有的几分钟歌舞片段。 我们都可... (展开)
9711 183 651回应 收起
鱼·无 2008-10-07 15:02:18

## 乡土小青年追求都市女精英成功指南

虽然，WALLE是一个浑身散发着遥远的乡下星球的泥土味（还有垃圾味）的破旧机器人，但它成功追求到了心中的女神——最高科技的代表作品、珠圆玉润身怀绝技的EWA。WALLE的成功给了我们珍贵的启示： 1、即使是在遥远偏僻的乡下，你也得是个骨干、小才子什么的。虽然咱们WALLE看起... (展开)
4288 207 354回应 收起
梅威斯 2009-01-15 10:19:59

## 一些有趣的幕后花絮

1. 给Wall E配音的是Ben Burtt，他是两座奥斯卡得主，也是这部电影的声效/配音/录制设计师。不只是Wall E，其他很多机器人的配音都是他，包括小MO. 2. 苹果公司的产品多次出现在电影中： -当Wall E充电完成启动时的声音是苹果电脑的开机声音 -Wall E每天晚上看的电影是通过ipod... (展开)
1374 23 111回应 收起
小转铃 2009-01-22 22:17:09

## 后后后……现代把妹指南

据说这片很多人看哭了，我是一向的泪点低，当然也哭得不行。不过哭点好像和大家不太一样，我是看到船长说where’s the blue sky where’s the grass的时候哭的，我想起了我那可怜的老家……上海。难道我竟有加入绿党的潜质…… 坚强地抹泪，并为大家奉上我观后匆匆总结的《后后... (展开)
1019 87 162回应 收起
poorwind 2008-12-21 22:15:53

## 这是个不能停留太久的世界

瓦力是一只被遗弃的机器人 他的工作是每天收集垃圾 这时的地球是被人类祸害的无可救要 进而被彻底废弃的巨大垃圾场 瓦力执行着程序任务 用肚子吃掉垃圾消化一下 变成正方体的建筑材料拉出来 拉的时候还要抖一下屁股 他在被人遗弃的世界里默默工作了700年 他还背着个小塑料箱 ... (展开)
1173 34 108回应 收起
老鸡｜扶立 2008-10-18 00:25:23

## 欢天喜地接受被屠杀

你一年能看多少电影？我不知道你有没有想过。我给自己计算过。平均每个月上一次电影院，看1张DVD，一年就是24部。每周看2部下载的、或者2部在线的，一年就是2乘52等于104部。那么全年合计大概130部左右。 一年130部，真是个不小的数字。到了将近年尾的时候，你能想起来几部？... (展开)
356 18 55回应 收起
小印子 2009-02-27 10:35:53

## 请将我的男人也变成瓦力吧

这篇影评可能有剧透

从前有一个小青年瓦力，因为容貌普通、个头不高、学历较低，而被分到了农村工作，负责垃圾整理工作。他心态很好，工作也很努力，还很有兴致地利用捡垃圾的工作捡了很多饶有情调的玩意儿，装饰自己的铁皮小屋。 有一天，一位长相白白净净、很萌很萌的大城市女城管被一... (展开)
277 18 68回应 收起
安东尼 2008-10-26 17:44:15

## 我的 名字 你的姓

终于 我和 小野同学在 懒洋洋的周日中午 看了 wall.e 其实这电影没上映的时候 我和小野就在 电影院看了片花 当时就决定要看 前面 魔术师和兔子的 那个挺搞笑 那个兔子很腹黑 魔术师很抗挫 之后就是 wall.e 太好看了 一个如 未来 apple机的 机器人 和一个 类似小学三年级 ... (展开)
265 21 58回应 收起

> 更多影评 3104篇

添加新讨论

## 讨论区 · · · · · ·

换掉主板和各种零件的瓦力还是之前的瓦力吗？ | 来自Paramount。 | 8 回应 | 2022-11-17 12:17:36
walle在电视上放的那些电影视频 | 来自沙与沫不及 | 2 回应 | 2022-11-13 19:47:35
阔以 | 来自小小花生酱拌面 |  | 2022-11-12 21:44:01
瓦力的梦想～牵女神的手手 | 来自西府海棠香如雪 |  | 2022-11-07 22:22:56
伊娃在地球上为啥会停止运行啊？ | 来自森林冰火人 | 1 回应 | 2022-11-06 21:17:05

> 去这部影片的讨论区（全部1013条）

## 关于《机器人总动员》的问题 · · · · · · ( 全部20个 )

- 为什么eva一开始看见小强没当它是生命? 15人回答
- 你們怎麼就判斷性別了呢…？ 19人回答

> 全部20个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 西瓜视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【内牛满面】 (影志)
- 【豆瓣高分动画长片】 (影志)
- {北美电影票房总排行} (荔枝超人)
- 【爱看动画】 (影志)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)

## 谁在看这部电影 · · · · · ·

- 豆友o0SEXYHtb8
  刚刚 想看
- 慢慢儿
  1分钟前 看过
- Wriprin
  1分钟前 想看

2212728人看过 / 313328人想看

订阅机器人总动员的评论:
feed: rss 2.0